@@ -143,7 +143,7 @@ CREATE TABLE node_cksum (
 	cksum		text		DEFAULT ''	NOT NULL,
 	sync		char(128)		DEFAULT ''	NOT NULL
 );
-CREATE INDEX node_cksum_cksum_1 on node_cksum (nodeid,tablename,recordid,cksumtype);
+CREATE INDEX node_cksum_1 on node_cksum (nodeid,cksumtype,tablename,recordid);
 CREATE TABLE services_times (
 	timeid		bigint		DEFAULT '0'	NOT NULL,
 	serviceid		bigint		DEFAULT '0'	NOT NULL,
